@@ -3,7 +3,7 @@
 
 __author__ = "jboursier"
 __copyright__ = "Copyright 2022, Malwarebytes"
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 __maintainer__ = "jboursier"
 __email__ = "jboursier@malwarebytes.com"
 __status__ = "Production"
@@ -31,7 +31,7 @@ def main() -> None:
 
 @click.group()
 def cli() -> None:
-    """ghas-cli is a Python3 utility to interact with Github Advanced Security.
+    """ghas-cli is a Python3 utility to interact with GitHub Advanced Security.
 
     Get help: `@jboursier` on Slack
     """
